@@ -118,14 +118,14 @@ print_it($F, 'Rounded Box Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->box({'x' => rand($XX), 'y' => rand($YY), 'xx' => rand($XX), 'yy' => rand($YY), 'radius' => rand(20) + 1});
+    $F->box({'x' => rand($XX), 'y' => rand($YY), 'xx' => rand($XX), 'yy' => rand($YY), 'radius' => rand($XX / 16)});
 }
 
 print_it($F, 'Filled Rounded Box Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->box({'x' => rand($XX), 'y' => rand($YY), 'xx' => rand($XX), 'yy' => rand($YY), 'radius' => rand(80) + 1, 'filled' => 1});
+    $F->box({'x' => rand($XX), 'y' => rand($YY), 'xx' => rand($XX), 'yy' => rand($YY), 'radius' => rand($XX / 16), 'filled' => 1});
 }
 
 print_it($F, 'Gradient Rounded Box Test');
@@ -138,7 +138,7 @@ while (time < $s) {
             'y'        => rand($YY),
             'xx'       => rand($XX),
             'yy'       => rand($YY),
-            'radius'   => rand(80) + 1,
+            'radius'   => rand($XX / 16),
             'filled'   => 1,
             'gradient' => {
                 'start' => {
@@ -160,14 +160,14 @@ print_it($F, 'Circle Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->circle({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y)});
+    $F->circle({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_x)});
 }
 
 print_it($F, 'Filled Circle Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->circle({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y), 'filled' => 1});
+    $F->circle({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_x), 'filled' => 1});
 }
 
 print_it($F, 'Gradient Circle Test');
@@ -178,7 +178,7 @@ while (time < $s) {
         {
             'x'        => rand($XX),
             'y'        => rand($YY),
-            'radius'   => rand($center_y),
+            'radius'   => rand($center_x),
             'filled'   => 1,
             'gradient' => {
                 'start' => {
@@ -200,21 +200,21 @@ print_it($F, 'Arc Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->arc({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360)});
+    $F->arc({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_x), 'start_degrees' => rand(360), 'end_degrees' => rand(360)});
 }
 
 print_it($F, 'Poly Arc Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->poly_arc({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360)});
+    $F->poly_arc({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_x), 'start_degrees' => rand(360), 'end_degrees' => rand(360)});
 }
 
 print_it($F, 'Filled Pie Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->filled_pie({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360)});
+    $F->filled_pie({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_x), 'start_degrees' => rand(360), 'end_degrees' => rand(360)});
 }
 
 print_it($F, 'Gradient Filled Pie Test');
@@ -225,7 +225,7 @@ while (time < $s) {
         {
             'x'             => rand($XX),
             'y'             => rand($YY),
-            'radius'        => rand($center_y),
+            'radius'        => rand($center_x),
             'start_degrees' => rand(360),
             'end_degrees'   => rand(360),
             'gradient'      => {
