@@ -3,26 +3,25 @@
 # and shows the only way threads will work with it.
 
 use strict;
-use Switch;
 
 use threads;
 use threads::shared;
+use Switch;
 use Graphics::Framebuffer;
 use Sys::CPU;
 use Term::ANSIScreen qw(:cursor :screen :color);
 
 $| = 1;
 
-our $VERSION = 2.00;
+our $VERSION = 2.01;
 
-my $mali          = 0;
 my $file          = 0;
 my $hold : shared = 0;
 my @waiting : shared;
 my $RUNNING : shared = 1;
 my $arg = join('', @ARGV);
 my $Threads = $arg =~ /(\d+)/ ? $1 : Sys::CPU::cpu_count();
-$mali = 1 if ($arg =~ /mali/i);    # Mali GPU correction mode
+
 $file = 1 if ($arg =~ /file/i);    # File Handle mode
 
 print "\nRunning on a ", Sys::CPU::cpu_type(), " with $Threads threads\n";
@@ -31,16 +30,16 @@ sleep 2;
 my @framebuffer;
 my $splash = 1;
 foreach my $thr (0 .. $Threads) {
-    $framebuffer[$thr] = Graphics::Framebuffer->new('FB_DEVICE' => '/dev/fb0', 'FILE_MODE' => $file, 'MALI' => $mali, 'SPLASH' => $splash);
+    $framebuffer[$thr] = Graphics::Framebuffer->new('FILE_MODE' => $file, 'SPLASH' => $splash);
     $splash = 0;
 }
 my ($screen_width, $screen_height) = $framebuffer[0]->screen_dimensions();
 
 my $top = 16 * $Threads;    # Font height * # of threads
 
-$framebuffer[0]->cls('OFF');
+$framebuffer[0]->cls();
 cls;
-print STDERR setscroll(1, $Threads) if ($screen_width > 255);    # prevents Perl errors from flooding the screen
+
 $SIG{'QUIT'} = \&finish;
 $SIG{'INT'}  = \&finish;
 my @thrd;
@@ -51,7 +50,7 @@ foreach my $page (1 .. $Threads) {
             my $Page = shift;
             my $top  = shift;
             if (defined($framebuffer[$Page]->{'ERROR'})) {
-                print STDERR locate($Page, 1), clline, "ERROR: Thread $Page, $framebuffer[$Page]->{'ERROR'}" if ($screen_width > 255);
+                print locate($Page, 1), clline, "ERROR: Thread $Page, $framebuffer[$Page]->{'ERROR'}" if ($screen_width > 255);
             }
             $framebuffer[$page]->clip_set({'x' => 0, 'y' => $top, 'xx' => $screen_width, 'yy' => $screen_height}) if ($screen_width > 255);
             while ($RUNNING) {
@@ -61,10 +60,13 @@ foreach my $page (1 .. $Threads) {
                     threads->yield();
                     $waiting[$Page] = 0;
                     sleep 1;
-                } ## end while ($hold && $RUNNING)
+                    select(STDOUT);$|=1;
+                }
                 $waiting[$Page] = 1;
-            } ## end while ($RUNNING)
+                select(STDOUT);$|=1;
+            }
             print locate($Page + 1, 1), clline, colored(['black on_green'], "Thread $Page"), ' Finished' if ($screen_width > 255);
+            select(STDOUT);$|=1;
         },
         $page,
         $top
@@ -111,6 +113,7 @@ sub attract {
 
     $framebuffer[$page]->set_color({'red' => $red, 'green' => $grn, 'blue' => $blu});
     $framebuffer[$page]->draw_mode($mode);
+
     switch ($type) {
         case 0 {
             print locate($page, 1), clline, colored(['black on_green'], "Thread $page"), sprintf(' Plotting point at %04d,%04d with pixel size %02d', $x, $y, $size);
@@ -296,7 +299,6 @@ sub arctype {
 
 sub finish {
     $RUNNING = 0;
-    print setscroll(1, $Threads + 1);
     print locate(1, 1), "WAITING FOR THREADS TO FINISH...";
     while (threads->list(threads::running)) {
         threads->yield();
